#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ini
version:              0.4.1
visibility:           public
id:                   ini-0.4.1-8AJRyUa6xGo7u8wlfpPEsv
key:                  ini-0.4.1-8AJRyUa6xGo7u8wlfpPEsv
license:              BSD-3-Clause
copyright:            2013 Chris Done
maintainer:           chrisdone@gmail.com
author:               Chris Done
homepage:             http://github.com/chrisdone/ini
synopsis:             Quick and easy configuration files in the INI format.
description:          Quick and easy configuration files in the INI format.
category:             Data, Configuration
abi:                  502eb2ed7bc0b36307abba6c49037561
exposed:              True
exposed-modules:      Data.Ini
import-dirs:          /usr/lib/ghc-8.10.5/site-local/ini-0.4.1
library-dirs:         /usr/lib/ghc-8.10.5/site-local/ini-0.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/ini-0.4.1
hs-libraries:         HSini-0.4.1-8AJRyUa6xGo7u8wlfpPEsv
depends:
    attoparsec-0.14.1-CDW2c9fsk3y4jVQKNBcpib base-4.14.2.0 text-1.2.4.1
    unordered-containers-0.2.14.0-JpdjDmlqBJN4PAu3jIj4Ya

haddock-interfaces:   /usr/share/doc/haskell-ini/html/ini.haddock
haddock-html:         /usr/share/doc/haskell-ini/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

